=======
Credits
=======

Development Lead
----------------

* Harsh Sinha <harsh.sinha@pitt.edu>
* Pradeep Raamana <raamana@gmail.com>

Contributors
------------

* Yaroslav Halchenko
* Tanupat Boonchalermvichien
* Will Foran

